.. _doc-install:

#######################
  Camelot Installation 
#######################

From the Python Package Index
=============================

First, make sure you have setup tools installed, `Setup tools <http://pypi.python.org/pypi/setuptools>`_.
If you are using a debian based distribution, you can type::

  sudo apt-get install python-setuptools

Then use easy_install to install Camelot, under Linux this would be done by typing::

  sudo easy_install camelot

Microsoft Windows
=================

